# pyright: reportUnusedImport=false
import struct
from typing import Optional, Self, Sequence
from .. import abcs
from ..core import Request, serialize_bytes_to
_bytes = bytes | bytearray | memoryview
def send_code(*, phone_number: str, api_id: int, api_hash: str, settings: abcs.CodeSettings) -> Request[abcs.auth.SentCode]:
    _buffer = bytearray(b'O$w\xa6')
    serialize_bytes_to(_buffer, phone_number.encode('utf-8'))
    _buffer += struct.pack('<i', api_id)
    serialize_bytes_to(_buffer, api_hash.encode('utf-8'))
    settings._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def sign_up(*, phone_number: str, phone_code_hash: str, first_name: str, last_name: str) -> Request[abcs.auth.Authorization]:
    _buffer = bytearray(b"'\xe4\xee\x80")
    serialize_bytes_to(_buffer, phone_number.encode('utf-8'))
    serialize_bytes_to(_buffer, phone_code_hash.encode('utf-8'))
    serialize_bytes_to(_buffer, first_name.encode('utf-8'))
    serialize_bytes_to(_buffer, last_name.encode('utf-8'))
    return Request(b'' + _buffer)
def sign_in(*, phone_number: str, phone_code_hash: str, phone_code: Optional[str], email_verification: Optional[abcs.EmailVerification]) -> Request[abcs.auth.Authorization]:
    _buffer = bytearray(b'Q\xa9R\x8d')
    flags = (0 if phone_code is None else 1) | (0 if email_verification is None else 2)
    _buffer += struct.pack('<I', flags)
    serialize_bytes_to(_buffer, phone_number.encode('utf-8'))
    serialize_bytes_to(_buffer, phone_code_hash.encode('utf-8'))
    if phone_code is not None:
      serialize_bytes_to(_buffer, phone_code.encode('utf-8'))
    if email_verification is not None:
      email_verification._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def log_out() -> Request[abcs.auth.LoggedOut]:
    _buffer = bytearray(b'\x19\xbar>')
    return Request(b'' + _buffer)
def reset_authorizations() -> Request[bool]:
    _buffer = bytearray(b'\x1a\r\xab\x9f')
    return Request(b'' + _buffer)
def export_authorization(*, dc_id: int) -> Request[abcs.auth.ExportedAuthorization]:
    _buffer = bytearray(b'\xcd\xff\xbf\xe5')
    _buffer += struct.pack('<i', dc_id)
    return Request(b'' + _buffer)
def import_authorization(*, id: int, bytes: _bytes) -> Request[abcs.auth.Authorization]:
    _buffer = bytearray(b'\xad}z\xa5')
    _buffer += struct.pack('<q', id)
    serialize_bytes_to(_buffer, bytes)
    return Request(b'' + _buffer)
def bind_temp_auth_key(*, perm_auth_key_id: int, nonce: int, expires_at: int, encrypted_message: _bytes) -> Request[bool]:
    _buffer = bytearray(b'\x05*\xd4\xcd')
    _buffer += struct.pack('<qqi', perm_auth_key_id, nonce, expires_at)
    serialize_bytes_to(_buffer, encrypted_message)
    return Request(b'' + _buffer)
def import_bot_authorization(*, flags: int, api_id: int, api_hash: str, bot_auth_token: str) -> Request[abcs.auth.Authorization]:
    _buffer = bytearray(b',\xff\xa3g')
    _buffer += struct.pack('<ii', flags, api_id)
    serialize_bytes_to(_buffer, api_hash.encode('utf-8'))
    serialize_bytes_to(_buffer, bot_auth_token.encode('utf-8'))
    return Request(b'' + _buffer)
def check_password(*, password: abcs.InputCheckPasswordSrp) -> Request[abcs.auth.Authorization]:
    _buffer = bytearray(b'\x16M\x8b\xd1')
    password._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def request_password_recovery() -> Request[abcs.auth.PasswordRecovery]:
    _buffer = bytearray(b'f\xbc\x97\xd8')
    return Request(b'' + _buffer)
def recover_password(*, code: str, new_settings: Optional[abcs.account.PasswordInputSettings]) -> Request[abcs.auth.Authorization]:
    _buffer = bytearray(b'pl\t7')
    flags = (0 if new_settings is None else 1)
    _buffer += struct.pack('<I', flags)
    serialize_bytes_to(_buffer, code.encode('utf-8'))
    if new_settings is not None:
      new_settings._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def resend_code(*, phone_number: str, phone_code_hash: str) -> Request[abcs.auth.SentCode]:
    _buffer = bytearray(b'\xbf\xa9\xf1>')
    serialize_bytes_to(_buffer, phone_number.encode('utf-8'))
    serialize_bytes_to(_buffer, phone_code_hash.encode('utf-8'))
    return Request(b'' + _buffer)
def cancel_code(*, phone_number: str, phone_code_hash: str) -> Request[bool]:
    _buffer = bytearray(b'x\x05\x04\x1f')
    serialize_bytes_to(_buffer, phone_number.encode('utf-8'))
    serialize_bytes_to(_buffer, phone_code_hash.encode('utf-8'))
    return Request(b'' + _buffer)
def drop_temp_auth_keys(*, except_auth_keys: Sequence[int]) -> Request[bool]:
    _buffer = bytearray(b'\x88\xa1H\x8e')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(except_auth_keys))
    _buffer += struct.pack(f'<{len(except_auth_keys)}q', *except_auth_keys)
    return Request(b'' + _buffer)
def export_login_token(*, api_id: int, api_hash: str, except_ids: Sequence[int]) -> Request[abcs.auth.LoginToken]:
    _buffer = bytearray(b'\xfe\x85\xe0\xb7')
    _buffer += struct.pack('<i', api_id)
    serialize_bytes_to(_buffer, api_hash.encode('utf-8'))
    _buffer += struct.pack('<ii', 0x1cb5c415, len(except_ids))
    _buffer += struct.pack(f'<{len(except_ids)}q', *except_ids)
    return Request(b'' + _buffer)
def import_login_token(*, token: _bytes) -> Request[abcs.auth.LoginToken]:
    _buffer = bytearray(b'\xe4\\\xac\x95')
    serialize_bytes_to(_buffer, token)
    return Request(b'' + _buffer)
def accept_login_token(*, token: _bytes) -> Request[abcs.Authorization]:
    _buffer = bytearray(b'M\xad\x94\xe8')
    serialize_bytes_to(_buffer, token)
    return Request(b'' + _buffer)
def check_recovery_password(*, code: str) -> Request[bool]:
    _buffer = bytearray(b'y\xbf6\r')
    serialize_bytes_to(_buffer, code.encode('utf-8'))
    return Request(b'' + _buffer)
def import_web_token_authorization(*, api_id: int, api_hash: str, web_auth_token: str) -> Request[abcs.auth.Authorization]:
    _buffer = bytearray(b'\xa9s\xb8-')
    _buffer += struct.pack('<i', api_id)
    serialize_bytes_to(_buffer, api_hash.encode('utf-8'))
    serialize_bytes_to(_buffer, web_auth_token.encode('utf-8'))
    return Request(b'' + _buffer)
def request_firebase_sms(*, phone_number: str, phone_code_hash: str, safety_net_token: Optional[str], ios_push_secret: Optional[str]) -> Request[bool]:
    _buffer = bytearray(b'PKF\x89')
    flags = (0 if safety_net_token is None else 1) | (0 if ios_push_secret is None else 2)
    _buffer += struct.pack('<I', flags)
    serialize_bytes_to(_buffer, phone_number.encode('utf-8'))
    serialize_bytes_to(_buffer, phone_code_hash.encode('utf-8'))
    if safety_net_token is not None:
      serialize_bytes_to(_buffer, safety_net_token.encode('utf-8'))
    if ios_push_secret is not None:
      serialize_bytes_to(_buffer, ios_push_secret.encode('utf-8'))
    return Request(b'' + _buffer)
def reset_login_email(*, phone_number: str, phone_code_hash: str) -> Request[abcs.auth.SentCode]:
    _buffer = bytearray(b'\x93\x01\x96~')
    serialize_bytes_to(_buffer, phone_number.encode('utf-8'))
    serialize_bytes_to(_buffer, phone_code_hash.encode('utf-8'))
    return Request(b'' + _buffer)
